@@ -1,19 +1,19 @@
 use serde::{Deserialize, Serialize};
 use tdn_types::{
     group::GroupId,
-    primitive::{PeerAddr, Result},
+    primitive::{PeerId, Result},
 };
 
 #[derive(Serialize, Deserialize, Clone)]
 pub struct User {
     pub id: GroupId,
-    pub addr: PeerAddr,
+    pub addr: PeerId,
     pub name: String,
     pub avatar: Vec<u8>,
 }
 
 impl User {
-    pub fn new(id: GroupId, addr: PeerAddr, name: String, avatar: Vec<u8>) -> Result<Self> {
+    pub fn new(id: GroupId, addr: PeerId, name: String, avatar: Vec<u8>) -> Result<Self> {
         Ok(Self {
             id,
             addr,
